pub struct HttpIncomingHandler<T: Guest> { /* private fields */ }Trait Implementations
Sourceimpl<T: Guest> Guest for HttpIncomingHandler<T>
impl<T: Guest> Guest for HttpIncomingHandler<T>
Sourcefn handle(request: IncomingRequest, response_out: ResponseOutparam)
fn handle(request: IncomingRequest, response_out: ResponseOutparam)
This function is invoked with an incoming HTTP Request, and a resource
response-outparam which provides the capability to reply with an HTTP
Response. The response is sent by calling the response-outparam.set
method, which allows execution to continue after the response has been
sent. This enables both streaming to the response body, and performing other
work. Read moreAuto Trait Implementations
impl<T> Freeze for HttpIncomingHandler<T>
impl<T> RefUnwindSafe for HttpIncomingHandler<T>where
T: RefUnwindSafe,
impl<T> Send for HttpIncomingHandler<T>where
T: Send,
impl<T> Sync for HttpIncomingHandler<T>where
T: Sync,
impl<T> Unpin for HttpIncomingHandler<T>where
T: Unpin,
impl<T> UnsafeUnpin for HttpIncomingHandler<T>
impl<T> UnwindSafe for HttpIncomingHandler<T>where
T: UnwindSafe,