pub struct Duration(/* private fields */);Expand description
A Duration type to represent a span of time, typically used for system timeouts.
This type wraps std::time::Duration so we can implement traits on it
without coherence issues, just like if we were implementing this in the
stdlib.
Implementations
Sourceimpl Duration
impl Duration
Sourcepub fn new(secs: u64, nanos: u32) -> Duration
pub fn new(secs: u64, nanos: u32) -> Duration
Creates a new Duration from the specified number of whole seconds and
additional nanoseconds.
Sourcepub fn from_secs(secs: u64) -> Duration
pub fn from_secs(secs: u64) -> Duration
Creates a new Duration from the specified number of whole seconds.
Sourcepub fn from_millis(millis: u64) -> Duration
pub fn from_millis(millis: u64) -> Duration
Creates a new Duration from the specified number of milliseconds.
Sourcepub fn from_micros(micros: u64) -> Duration
pub fn from_micros(micros: u64) -> Duration
Creates a new Duration from the specified number of microseconds.
Sourcepub fn from_nanos(nanos: u64) -> Duration
pub fn from_nanos(nanos: u64) -> Duration
Creates a new Duration from the specified number of nanoseconds.
Sourcepub fn from_secs_f64(secs: f64) -> Duration
pub fn from_secs_f64(secs: f64) -> Duration
Sourcepub fn from_secs_f32(secs: f32) -> Duration
pub fn from_secs_f32(secs: f32) -> Duration
Creates a new Duration from the specified number of seconds represented
as f32.
Panics
This constructor will panic if secs is not finite, negative or overflows Duration.
Sourcepub const fn as_secs(&self) -> u64
pub const fn as_secs(&self) -> u64
Returns the number of whole seconds contained by this Duration.
Sourcepub const fn as_millis(&self) -> u128
pub const fn as_millis(&self) -> u128
Returns the number of whole milliseconds contained by this Duration.