pub struct SystemTime(/* private fields */);Expand description
A measurement of the system clock, useful for talking to external entities like the file system or other processes.
Implementations
Sourceimpl SystemTime
impl SystemTime
pub fn now() -> SystemTime